@@ -5,9 +5,8 @@ from .base import BaseTable, engine, meta
 
 
 class KlineData(BaseTable):
-    def __init__(self, table_name="kline_data_1min", source=None, *args, **kwargs):
-        if source is not None:
-            table_name = f"{source.lower()}_{table_name}"
+    def __init__(self, table_name="kline_data_1min", prefix='com', suffix='com',  *args, **kwargs):
+        table_name = f"{prefix.lower()}_{table_name}_{suffix.lower()}"
 
         super(KlineData, self).__init__(table_name=table_name, *args, **kwargs)
         self.table = Table(self.table_name, meta,
@@ -19,7 +18,7 @@ class KlineData(BaseTable):
                            Column('high', Float, comment='high', default=0),
                            Column('vol', Float, comment='vol', default=0),
                            extend_existing=True,
-                           autoload=True
+                           # autoload=True
                            )
         self.create()
 
